@@ -15,15 +15,15 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} _com ()
+## @defvr Constant _com
 ## Return numeric representation of the common decoration
-## @end deftypefn
+## @end defvr
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
 ## Created: 2015-04-18
 
 function d = _com ()
-## See IEEE Std 1788-2015 14.4 Interchange representations and encodings
-persistent d = uint8 (16);
+  ## See IEEE Std 1788-2015 14.4 Interchange representations and encodings
+  d = uint8 (16);
 endfunction
